| actuaRE-package | R Documentation |
Fits random effects models for multi-level/high-cardinality factors using credibility theory (Buhlmann-Straub for single-level, Jewell for hierarchical structures), GLM extensions following Ohlsson (2008) <doi:10.1080/03461230701878612>, or Tweedie generalized linear mixed models. Provides functions for model fitting, visualization, and prediction. See Campo, B.D.C. and Antonio, K. (2023) <doi:10.1080/03461238.2022.2161413>.
Campo, B.D.C. and Antonio, Katrien (2023). Insurance pricing with hierarchically structured data an illustration with a workers' compensation insurance portfolio. Scandinavian Actuarial Journal, doi: 10.1080/03461238.2022.2161413
Dannenburg, D. R., Kaas, R. and Goovaerts, M. J. (1996). Practical actuarial credibility models. Amsterdam: IAE (Institute of Actuarial Science and Econometrics of the University of Amsterdam).
Jewell, W. S. (1975). The use of collateral data in credibility theory: a hierarchical model. Laxenburg: IIASA.
Ohlsson, E. (2005). Simplified estimation of structure parameters in hierarchical credibility. Presented at the Zurich ASTIN Colloquium.
Ohlsson, E. (2008). Combining generalized linear models and credibility models in practice. Scandinavian Actuarial Journal 2008(4), 301–314.
buhlmannStraub
buhlmannStraubGLM
buhlmannStraubTweedie
hierCredibility
hierCredGLM
hierCredTweedie
tweedieGLMM
BalanceProperty
library(actuaRE)
# Vignette of the package
vignette(package = "actuaRE")
# Load data
data(hachemeisterLong)
data(dataCar)
# Hierarchical credibility model of Jewell
fit = hierCredibility(ratio, weight, cohort, state, hachemeisterLong)
# Combination of the hierarchical credibility model with a GLM (Ohlsson, 2008)
fit = hierCredGLM(Y ~ area + (1 | VehicleType / VehicleBody), dataCar, weights = w,
p = 1.7)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.