Class "hierCredibility" of fitted hierarchical credibility models
# S3 method for hierCredibility
print(x, ...)# S3 method for hierCredibility
summary(object, ...)
# S3 method for hierCredibility
fitted(object, ...)
The function hierCredibility returns an object of class hierCredibility, which has the following slots:
the matched call
Whether additive or multiplicative hierarchical credibility model is used.
The estimated variance components. s2 is the estimated variance of the individual contracts,
tausq the estimate of \(Var(V[j])\) and nusq is the estimate of \(Var(V[jk])\).
The estimated averages at the portfolio level (intercept term \(\mu\)), at the first hierarchical level (\(bar(Y)[\%.\% j \%.\% \%.\%]^z\)) and at the second hierarchical level (\(bar(Y)[\%.\% jk \%.\%]\)).
The weights at the first hierarchical level \(z[j\%.\%]\) and at the second hierarchical level \(w[\%.\%jk\%.\%]\).
The credibility weights at the first hierarchical level \(q[j\%.\%]\) and at the second hierarchical level \(z[jk]\).
The overall expectation \(widehat(\mu)\), sector expectation \(widehat(V)[j]\) and group expectation \(widehat(V)[jk]\).
The estimated random effects \(widehat(U)[j]\) and \(widehat(U)[jk]\) of the sector and group, respectively.
Objects of type data.table with all intermediate results.
the fitted mean values, resulting from the model fit.
an object of class hierCredibility
currently ignored.
an object of class hierCredibility
print:Prints the call, the estimated variance parameters and the unique number of categories
of the hierarchical MLF. The ... argument is currently ignored. Returns an invisible copy of the original
object.
summary:In addition to the output of the print.hierCredibility function, the summary function
prints the random effect estimates as well. Returns an invisible copy of the original object.
fitted:Returns the fitted values.
hierCredibility