is.formula: Formula

View source: R/helperFunctions.R

is.formulaR Documentation

Formula

Description

Checks if the object is of the type formula

Usage

is.formula(x)

Arguments

x

the object.

Value

logical indicating if the object is a formula or not.

Examples

f = formula(y ~ x)
is.formula(f)

actuaRE documentation built on July 3, 2026, 5:07 p.m.