| plotRE | R Documentation |
Using this function, you can create plots of the random effect estimates from fitted random effects models. To make
the plots, we rely on the ggplot2 package.
plotRE(
obj,
levelRE = c("all", "first", "second"),
colour = "black",
plot = TRUE
)
obj |
an object of type |
levelRE |
indicates which hierarchical level has to be used. |
colour |
colour for |
plot |
logical indicating if the |
a list with ggplot objects.
data("tweedietraindata")
fitHGLM <- hierCredGLM(y ~ x1 + (1 | cluster / subcluster), tweedietraindata, weights = wt)
plotRE(fitHGLM)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.