Class "buhlmannStraubGLM" of fitted Buhlmann-Straub GLM credibility models
# S3 method for buhlmannStraubGLM
predict(object, newdata = NULL, ...)# S3 method for buhlmannStraubGLM
print(x, ...)
# S3 method for buhlmannStraubGLM
summary(object, ...)
# S3 method for buhlmannStraubGLM
fitted(object, ...)
The function buhlmannStraubGLM returns an object of class buhlmannStraubGLM, which has the following slots:
the matched call
results of the Buhlmann-Straub credibility model.
the results from fitting the GLM part.
total number of iterations.
logical indicating whether the algorithm converged.
object that summarizes the unique levels of each of the contract-specific covariates.
the fitted mean values, resulting from the model fit.
the weights (exposure) initially supplied.
if requested, the response vector.
an object of class buhlmannStraubGLM
optionally, a data frame in which to look for variables with which to predict.
currently ignored.
an object of class buhlmannStraubGLM
print:Prints the call, convergence status, number of iterations, and GLM summary.
The ... argument is currently ignored. Returns an invisible copy of the original object.
summary:In addition to the output of the print.buhlmannStraubGLM function, the summary function
prints the credibility results and random effect estimates as well. Returns an invisible copy of the original object.
fitted:Returns the fitted values.
predict:Predict method for new data.
ranef:Returns the random effects (cluster relativities).
fixef:Returns the fixed effects coefficients.
weights:Returns either credibility weights or exposure weights.
buhlmannStraubGLM