Learn R Programming

actuaRE (version 1.0.0)

predict.buhlmannStraubTweedie: Class "buhlmannStraubTweedie" of fitted Buhlmann-Straub GLM credibility models

Description

Class "buhlmannStraubTweedie" of fitted Buhlmann-Straub GLM credibility models

Usage

# S3 method for buhlmannStraubTweedie
predict(object, newdata = NULL, ...)

# S3 method for buhlmannStraubTweedie print(x, ...)

# S3 method for buhlmannStraubTweedie summary(object, ...)

# S3 method for buhlmannStraubTweedie fitted(object, ...)

Value

The function buhlmannStraubTweedie returns an object of class buhlmannStraubTweedie, which has the following slots:

call

the matched call

CredibilityResults

results of the Buhlmann-Straub credibility model.

fitGLM

the results from fitting the GLM part.

iter

total number of iterations.

Converged

logical indicating whether the algorithm converged.

LevelsCov

object that summarizes the unique levels of each of the contract-specific covariates.

fitted.values

the fitted mean values, resulting from the model fit.

prior.weights

the weights (exposure) initially supplied.

y

if requested, the response vector.

Arguments

object

an object of class buhlmannStraubTweedie

newdata

optionally, a data frame in which to look for variables with which to predict.

...

currently ignored.

x

an object of class buhlmannStraubTweedie

S3 methods

print:

Prints the call, convergence status, number of iterations, and GLM summary. The ... argument is currently ignored. Returns an invisible copy of the original object.

summary:

In addition to the output of the print.buhlmannStraubTweedie function, the summary function prints the credibility results and random effect estimates as well. Returns an invisible copy of the original object.

fitted:

Returns the fitted values.

predict:

Predict method for new data.

ranef:

Returns the random effects (cluster relativities).

fixef:

Returns the fixed effects coefficients.

weights:

Returns either credibility weights or exposure weights.

See Also

buhlmannStraubTweedie