Learn R Programming

actuaRE (version 0.1.7)

predict.hierCredGLM: Model predictions

Description

Obtain predictions based on the model fit with hierCredGLM

Usage

# S3 method for hierCredGLM
predict(object, newdata = NULL, ...)

Value

If newdata is omitted the predictions are based on the data used for the fit.

Arguments

object

a model object for which prediction is desired.

newdata

optionally, a data frame in which to look for variables with which to predict. If omitted, the fitted values are used.

...

arguments passed to glm

Details

The random effects are taken into account by specifying these as an offset in the predict.glm function.

See Also

hierCredGLM