Learn R Programming

actuaRE (version 0.1.7)

predict.hierCredibility: Model predictions

Description

Obtain predictions based on a model fit with hierCredibility

Usage

# S3 method for hierCredibility
predict(object, newdata = NULL, ...)

Value

If newdata is omitted the predictions are based on the data used for the fit.

Arguments

object

a model object for which prediction is desired.

newdata

optionally, a data frame in which to look for variables with which to predict. If omitted, the fitted values are used.

...

ignored.

See Also

hierCredibility