Learn R Programming

actuaRE (version 0.1.7)

ranef-actuaRE: Extract the random effect estimates from a fitted random effects model

Description

A generic function to extract the estimates/predictions of the random effects from a fitted random effects model.

Usage

# S3 method for hierCredibility
ranef(object, ...)

# S3 method for hierCredGLM ranef(object, ...)

# S3 method for hierCredTweedie ranef(object, ...)

Value

A list of data frames, one for each grouping factor for the random effects. The number of rows in the data frame is the number of levels of the grouping factor. The first (two) columns correspond(s) to the grouping factor. The last column corresponds to the estimated random effect.

Arguments

object

an object of type hierCredibility, hierCredGLM or hierCredTweedie

...

Currently ignored.