| tweedieGLMM | R Documentation |
This function first estimates the random effects model using Ohlsson's GLMC algorithm (Ohlsson, 2008) and then uses these estimates as initial estimates when fitting a Tweedie GLMM. Supports both single random effects and nested random effects.
tweedieGLMM(
formula,
data,
weights,
muHatGLM = FALSE,
epsilon = 1e-04,
maxiter = 500,
verbose = FALSE,
balanceProperty = TRUE
)
formula |
object of type |
data |
an object that is coercible by |
weights |
variable name of the exposure weight. |
muHatGLM |
indicates which estimate has to be used in the algorithm for the intercept term. Default is |
epsilon |
positive convergence tolerance |
maxiter |
maximum number of iterations. |
verbose |
logical indicating if output should be produced during the algorithm. |
balanceProperty |
logical indicating if the balance property should be satisfied. |
an object of class cpglmm, containing the model fit.
Campo, B.D.C. and Antonio, Katrien (2023). Insurance pricing with hierarchically structured data an illustration with a workers' compensation insurance portfolio. Scandinavian Actuarial Journal, doi: 10.1080/03461238.2022.2161413
Ohlsson, E. (2008). Combining generalized linear models and credibility models in practice. Scandinavian Actuarial Journal 2008(4), 301–314.
cpglmm, hierCredTweedie
# Nested random effects example
data("tweedietraindata")
fit = tweedieGLMM(y ~ x1 + (1 | cluster / subcluster), tweedietraindata, weights = wt)
fit
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.