Learn R Programming

actuaRE (version 0.1.7)

weights-actuaRE: Extract the model weights

Description

weights is a generic function which extracts fitting weights from objects returned by modeling functions. Methods can make use of napredict methods to compensate for the omission of missing values. The default methods does so.

Usage

# S3 method for cpglm
weights(object, type = c("prior", "working"), ...)

# S3 method for hierCredGLM weights(object, type = c("prior", "working"), ...)

# S3 method for hierCredTweedie weights(object, type = c("prior", "working"), ...)

Value

Weights extracted from the object object: the default method looks for component "weights" and if not NULL

calls napredict on it.

Arguments

object

an object for which the extraction of model weights is meaningful. Can be either cpglm, glm, hierCredibility, hierCredGLM or hierCredTweedie

type

indicates if prior or working weights need to be extracted.

...

ignored

See Also

weights, cpglm, glm, hierCredibility, hierCredGLM or hierCredTweedie