buhlmannStraub: Buhlmann-Straub credibility model

View source: R/BuhlmannStraubModel.R

buhlmannStraubR Documentation

Buhlmann-Straub credibility model

Description

Fit a credibility model using the Buhlmann-Straub model.

Usage

buhlmannStraub(
  Yijt,
  wijt,
  MLFj,
  data,
  muHat = NULL,
  type = c("additive", "multiplicative"),
  returnData = FALSE
)

Arguments

Yijt

variable name of the response variable.

wijt

variable name of the exposure weight.

MLFj

variable name of the risk class or cluster.

data

an object that is coercible by as.data.table, containing the variables in the model.

muHat

estimate for the collective premium (portfolio mean). Default is NULL and in this case, the credibility-weighted estimator is used.

type

specifies whether the additive or multiplicative formulation of the credibility model is used. Default is additive.

returnData

Logical, indicates whether the data object has to be returned. Default is FALSE.

Value

An object of type buhlmannStraub with the following slots:

call

the matched call

type

Whether additive or multiplicative credibility model is used.

Variances

The estimated variance components. Sigma is the estimated within-group variance, and Tau is the estimate of the between-group variance.

Means

The estimated averages at the portfolio level (collective premium \hat{\mu}) and at the cluster level (weighted average \bar{Y}_j).

Weights

The total weights w_j for each cluster.

Credibility

The credibility factors z_j for each cluster.

Premiums

The collective premium \hat{\mu} and individual premiums \hat{V}_j for each cluster.

Relativity

The estimated random effects \hat{U}_j of each cluster.

RawResults

Object of type data.table with all intermediate results.

fitted.values

the fitted mean values, resulting from the model fit.

References

Buhlmann, H. and Straub, E. (1970). Glaubwurdigkeit fur Schadensatze. Mitteilungen der Vereinigung schweizerischer Versicherungsmathematiker, 70, 111-133.

Buhlmann, H. and Gisler, A. (2005). A Course in Credibility Theory and its Applications. Springer.

See Also

buhlmannStraub-class, plotRE, buhlmannStraubGLM, buhlmannStraubTweedie, tweedieGLMM, adjustIntercept, BalanceProperty

Examples

library(actuar)
library(actuaRE)
data("hachemeister", package = "actuar")
# Prepare data
X = as.data.frame(hachemeister)
Df = reshape(X, idvar = "state",
             varying = list(paste0("ratio.", 1:12), paste0("weight.", 1:12)),
             direction = "long")
# Fit Buhlmann-Straub model
fitBS = buhlmannStraub(ratio.1, weight.1, state, Df)
summary(fitBS)
# Compare with actuar package
fit <- cm(~state, hachemeister, ratios = ratio.1:ratio.12,
          weights = weight.1:weight.12)
summary(fit)

actuaRE documentation built on July 3, 2026, 5:07 p.m.