View source: R/BuhlmannStraubModel.R
| buhlmannStraub | R Documentation |
Fit a credibility model using the Buhlmann-Straub model.
buhlmannStraub(
Yijt,
wijt,
MLFj,
data,
muHat = NULL,
type = c("additive", "multiplicative"),
returnData = FALSE
)
Yijt |
variable name of the response variable. |
wijt |
variable name of the exposure weight. |
MLFj |
variable name of the risk class or cluster. |
data |
an object that is coercible by |
muHat |
estimate for the collective premium (portfolio mean). Default is |
type |
specifies whether the additive or multiplicative formulation of the credibility model is used. Default is additive. |
returnData |
Logical, indicates whether the data object has to be returned. Default is |
An object of type buhlmannStraub with the following slots:
call |
the matched call |
type |
Whether additive or multiplicative credibility model is used. |
Variances |
The estimated variance components. |
Means |
The estimated averages at the portfolio level (collective premium |
Weights |
The total weights |
Credibility |
The credibility factors |
Premiums |
The collective premium |
Relativity |
The estimated random effects |
RawResults |
Object of type |
fitted.values |
the fitted mean values, resulting from the model fit. |
Buhlmann, H. and Straub, E. (1970). Glaubwurdigkeit fur Schadensatze. Mitteilungen der Vereinigung schweizerischer Versicherungsmathematiker, 70, 111-133.
Buhlmann, H. and Gisler, A. (2005). A Course in Credibility Theory and its Applications. Springer.
buhlmannStraub-class, plotRE, buhlmannStraubGLM, buhlmannStraubTweedie,
tweedieGLMM, adjustIntercept, BalanceProperty
library(actuar)
library(actuaRE)
data("hachemeister", package = "actuar")
# Prepare data
X = as.data.frame(hachemeister)
Df = reshape(X, idvar = "state",
varying = list(paste0("ratio.", 1:12), paste0("weight.", 1:12)),
direction = "long")
# Fit Buhlmann-Straub model
fitBS = buhlmannStraub(ratio.1, weight.1, state, Df)
summary(fitBS)
# Compare with actuar package
fit <- cm(~state, hachemeister, ratios = ratio.1:ratio.12,
weights = weight.1:weight.12)
summary(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.