| predict.buhlmannStraub | R Documentation |
Class "buhlmannStraub" of fitted Buhlmann-Straub credibility models
## S3 method for class 'buhlmannStraub'
predict(object, newdata = NULL, ...)
## S3 method for class 'buhlmannStraub'
print(x, ...)
## S3 method for class 'buhlmannStraub'
summary(object, ...)
## S3 method for class 'buhlmannStraub'
fitted(object, ...)
object |
an object of class |
newdata |
optionally, a data frame in which to look for variables with which to predict. |
... |
currently ignored. |
x |
an object of class |
The function buhlmannStraub returns an object of class buhlmannStraub, which has the following slots:
call |
the matched call |
type |
Whether additive or multiplicative credibility model is used. |
Variances |
The estimated variance components. |
Means |
The estimated averages at the portfolio level (collective premium |
Weights |
The total weights |
Credibility |
The credibility factors |
Premiums |
The collective premium |
Relativity |
The estimated random effects |
RawResults |
Object of type |
fitted.values |
the fitted mean values, resulting from the model fit. |
print:Prints the call, the estimated variance parameters and the unique number of clusters.
The ... argument is currently ignored. Returns an invisible copy of the original object.
summary:In addition to the output of the print.buhlmannStraub function, the summary function
prints the cluster-level estimates as well. Returns an invisible copy of the original object.
fitted:Returns the fitted values.
buhlmannStraub
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.