- formula
object of type formula that specifies which model should be fitted. Syntax follows
lmer: e.g., Y ~ x1 + x2 + (1 | Cluster). Only one random effect is allowed.
- data
an object that is coercible by as.data.table, containing the variables in the model.
- weights
variable name of the exposure weight.
- p
the value for the power parameter of the Tweedie distribution, which is passed to tweedie. Default is 1.5.
- link.power
index of power link function, which is passed to tweedie. link.power = 0 produces a log-link.
Defaults to the canonical link, which is 1 - p.
- muHatGLM
indicates which estimate has to be used in the algorithm for the intercept term. Default is TRUE,
which uses the intercept as estimated by the GLM. If FALSE, the estimate of the Buhlmann-Straub credibility model is used.
- epsilon
positive convergence tolerance \(\epsilon\); the iterations converge when
\(||\theta[k] - \theta[k - 1]||^2_2/||\theta[k - 1]||^2_2 < \epsilon\). Here, \(\theta[k]\) is the parameter vector at the \(k^{th}\) iteration.
- maxiter
maximum number of iterations.
- maxiterGLM
maximum number of iterations when fitting the GLM part. Passed to glm.
- verbose
logical indicating if output should be produced during the algorithm.
- returnData
logical indicating if input data has to be returned.
- balanceProperty
logical indicating if the balance property should be satisfied.
- y
logical indicating whether the response vector should be returned as a component of the returned value.
- ...
arguments passed to glm