| buhlmannStraubTweedie | R Documentation |
Fit a single-level random effects model using Ohlsson's methodology combined with Buhlmann-Straub credibility.
This function estimates the power parameter p. For fixed p, see buhlmannStraubGLM.
buhlmannStraubTweedie(
formula,
data,
weights,
muHatGLM = FALSE,
epsilon = 1e-04,
maxiter = 500,
verbose = FALSE,
returnData = TRUE,
cpglmControl = list(bound.p = c(1.01, 1.99)),
balanceProperty = TRUE,
optimizer = "bobyqa",
y = TRUE,
...
)
formula |
object of type |
data |
an object that is coercible by |
weights |
variable name of the exposure weight. |
muHatGLM |
indicates which estimate has to be used in the algorithm for the intercept term. Set to |
epsilon |
positive convergence tolerance |
maxiter |
maximum number of iterations. |
verbose |
logical indicating if output should be produced during the algorithm. |
returnData |
logical indicating if input data has to be returned. |
cpglmControl |
a list of parameters to control the fitting process in the GLM part. By default,
|
balanceProperty |
logical indicating if the balance property should be satisfied. |
optimizer |
a character string that determines which optimization routine is to be used in estimating the index and the dispersion parameters.
Possible choices are |
y |
logical indicating whether the response vector should be returned as a component of the returned value. |
... |
arguments passed to |
When estimating the GLM part, this function uses the cpglm function from the cplm package.
An object of type buhlmannStraubTweedie with the following slots:
call |
the matched call |
CredibilityResults |
results of the Buhlmann-Straub credibility model. |
fitGLM |
the results from fitting the GLM part. |
iter |
total number of iterations. |
Converged |
logical indicating whether the algorithm converged. |
LevelsCov |
object that summarizes the unique levels of each of the contract-specific covariates. |
fitted.values |
the fitted mean values, resulting from the model fit. |
prior.weights |
the weights (exposure) initially supplied. |
y |
if requested, the response vector. Default is |
Campo, B.D.C. and Antonio, Katrien (2023). Insurance pricing with hierarchically structured data an illustration with a workers' compensation insurance portfolio. Scandinavian Actuarial Journal, doi: 10.1080/03461238.2022.2161413
Ohlsson, E. (2008). Combining generalized linear models and credibility models in practice. Scandinavian Actuarial Journal 2008(4), 301–314.
buhlmannStraubTweedie-class, buhlmannStraub, buhlmannStraubGLM,
hierCredTweedie, cpglm, plotRE, adjustIntercept, BalanceProperty
data("hachemeister", package = "actuar")
X = as.data.frame(hachemeister)
Df = reshape(X, idvar = "state",
varying = list(paste0("ratio.", 1:12), paste0("weight.", 1:12)),
direction = "long")
Df$time_factor = factor(Df$time)
fit = buhlmannStraubTweedie(ratio.1 ~ time_factor + (1 | state), Df,
weights = weight.1, epsilon = 1e-6)
summary(fit)
ranef(fit)
fixef(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.