- formula
object of type formula that specifies which model should be fitted. Syntax follows
lmer: e.g., Y ~ x1 + x2 + (1 | Cluster). Only one random effect is allowed.
- data
an object that is coercible by as.data.table, containing the variables in the model.
- weights
variable name of the exposure weight.
- muHatGLM
indicates which estimate has to be used in the algorithm for the intercept term. Default is TRUE,
which uses the intercept as estimated by the GLM. If FALSE, the estimate of the Buhlmann-Straub credibility model is used.
- epsilon
positive convergence tolerance \(\epsilon\); the iterations converge when
\(||\theta[k] - \theta[k - 1]||^2_2/||\theta[k - 1]||^2_2 < \epsilon\). Here, \(\theta[k]\) is the parameter vector at the \(k^{th}\) iteration.
- maxiter
maximum number of iterations.
- verbose
logical indicating if output should be produced during the algorithm.
- returnData
logical indicating if input data has to be returned.
- cpglmControl
a list of parameters to control the fitting process in the GLM part. By default,
cpglmControl = list(bound.p = c(1.01, 1.99)) which restricts the range of the power parameter p to [1.01, 1.99] in the fitting
process. This list is passed to cpglm.
- balanceProperty
logical indicating if the balance property should be satisfied.
- optimizer
a character string that determines which optimization routine is to be used in estimating the index and the dispersion parameters.
Possible choices are "nlminb" (the default, see nlminb), "bobyqa" (bobyqa) and "L-BFGS-B" (optim).
- y
logical indicating whether the response vector should be returned as a component of the returned value.
- ...
arguments passed to cpglm.