Fit a random effects model using Ohlsson's methodology. In this function you estimate the power parameter p. See hierCredGLM when
you want fix p.
hierCredTweedie(
formula,
data,
weights,
muHatGLM = TRUE,
epsilon = 1e-04,
maxiter = 500,
verbose = FALSE,
returnData = TRUE,
cpglmControl = list(bound.p = c(1.01, 1.99)),
balanceProperty = TRUE,
optimizer = "bobyqa",
y = TRUE,
...
)An object of type hierCredTweedie with the following slots:
the matched call
results of the hierarchical credibility model.
the results from fitting the GLM part.
total number of iterations.
logical indicating whether the algorithm converged.
object that summarizes the unique levels of each of the contract-specific covariates.
the fitted mean values, resulting from the model fit.
the weights (exposure) initially supplied.
if requested, the response vector. Default is TRUE.
object of type formula that specifies which model should be fitted. Syntax is the same as for
lmer and glmer. For example, Yijkt ~ x1 + x2 + (1 | Industry / Branch).
an object that is coercible by as.data.table, containing the variables in the model.
variable name of the exposure weight.
indicates which estimate has to be used in the algorithm for the intercept term. Default is TRUE,
which used the intercept as estimated by the GLM. If FALSE, the estimate of the hierarchical credibility model is used.
positive convergence tolerance \(\epsilon\); the iterations converge when \(||\theta[k] - \theta[k - 1]||^2[[2]]/||\theta[k - 1]||^2[[2]] < \epsilon\). Here, \(\theta[k]\) is the parameter vector at the \(k^{th}\) iteration.
maximum number of iterations.
logical indicating if output should be produced during the algorithm.
logical indicating if input data has to be returned.
a list of parameters to control the fitting process in the GLM part. By default,
cpglmControl = list(bound.p = c(1.01, 1.99)) which restricts the range of the power parameter p to [1.01, 1.99] in the fitting
process. This list is passed to cpglm.
logical indicating if the balance property should be satisfied.
a character string that determines which optimization routine is to be used in estimating the index and the dispersion parameters.
Possible choices are "nlminb" (the default, see nlminb), "bobyqa" (bobyqa) and "L-BFGS-B" (optim).
logical indicating whether the response vector should be returned as a component of the returned value.
arguments passed to cpglm.
When estimating the GLM part, this function uses the cpglm function from the cplm package.
Ohlsson, E. (2008). Combining generalized linear models and credibility models in practice. Scandinavian Actuarial Journal 2008(4), 301–314.
hierCredTweedie-class, fitted.hierCredTweedie, predict.hierCredTweedie, ranef-actuaRE,
weights-actuaRE, hierCredibility, hierCredGLM, cpglm, plotRE,
adjustIntercept, BalanceProperty
@references Campo, B.D.C. and Antonio, Katrien (2023). Insurance pricing with hierarchically structured data an illustration with a workers' compensation insurance portfolio. Scandinavian Actuarial Journal, doi: 10.1080/03461238.2022.2161413
# \donttest{
data("dataCar")
fit = hierCredTweedie(Y ~ area + (1 | VehicleType / VehicleBody), dataCar,
weights = w, epsilon = 1e-6)
fit
summary(fit)
ranef(fit)
fixef(fit)
# }
Run the code above in your browser using DataLab