Learn R Programming

actuaRE (version 0.1.7)

is.formula: Formula

Description

Checks if the object is of the type formula

Usage

is.formula(x)

Value

logical indicating if the object is a formula or not.

Arguments

x

the object.

Examples

Run this code
f = formula(y ~ x)
is.formula(f)

Run the code above in your browser using DataLab