powered by
Checks if the object is of the type formula
is.formula(x)
logical indicating if the object is a formula or not.
the object.
f = formula(y ~ x) is.formula(f)
Run the code above in your browser using DataLab