Class "buhlmannStraub" of fitted Buhlmann-Straub credibility models
# S3 method for buhlmannStraub
predict(object, newdata = NULL, ...)# S3 method for buhlmannStraub
print(x, ...)
# S3 method for buhlmannStraub
summary(object, ...)
# S3 method for buhlmannStraub
fitted(object, ...)
The function buhlmannStraub returns an object of class buhlmannStraub, which has the following slots:
the matched call
Whether additive or multiplicative credibility model is used.
The estimated variance components. Sigma is the estimated within-group variance,
and Tau is the estimate of the between-group variance.
The estimated averages at the portfolio level (collective premium \(\hat{\mu}\)) and at the cluster level (weighted average \(\bar{Y}_j\)).
The total weights \(w_j\) for each cluster.
The credibility factors \(z_j\) for each cluster.
The collective premium \(\hat{\mu}\) and individual premiums \(\hat{V}_j\) for each cluster.
The estimated random effects \(\hat{U}_j\) of each cluster.
Object of type data.table with all intermediate results.
the fitted mean values, resulting from the model fit.
an object of class buhlmannStraub
optionally, a data frame in which to look for variables with which to predict.
currently ignored.
an object of class buhlmannStraub
print:Prints the call, the estimated variance parameters and the unique number of clusters.
The ... argument is currently ignored. Returns an invisible copy of the original object.
summary:In addition to the output of the print.buhlmannStraub function, the summary function
prints the cluster-level estimates as well. Returns an invisible copy of the original object.
fitted:Returns the fitted values.
buhlmannStraub