tweedieGLMM: Fitting a Tweedie GLMM, using initial estimates from credibility models
Description
This function first estimates the random effects model using Ohlsson's GLMC algorithm (Ohlsson, 2008) and then uses
these estimates as initial estimates when fitting a Tweedie GLMM. Supports both single random effects and
nested random effects.
an object of class cpglmm, containing the model fit.
Arguments
formula
object of type formula that specifies which model should be fitted. Syntax is the same as for
lmer and glmer. For single random effect: Y ~ x1 + x2 + (1 | Cluster).
For nested random effects: Y ~ x1 + x2 + (1 | cluster / subcluster).
data
an object that is coercible by as.data.table, containing the variables in the model.
weights
variable name of the exposure weight.
muHatGLM
indicates which estimate has to be used in the algorithm for the intercept term. Default is FALSE,
which uses the intercept as estimated by the credibility model. If TRUE, the estimate of the GLM is used.
epsilon
positive convergence tolerance \(\epsilon\); the iterations converge when
\(||\theta[k] - \theta[k - 1]||^2_2/||\theta[k - 1]||^2_2 < \epsilon\). Here, \(\theta[k]\) is the parameter vector at the \(k^{th}\) iteration.
maxiter
maximum number of iterations.
verbose
logical indicating if output should be produced during the algorithm.
balanceProperty
logical indicating if the balance property should be satisfied.
References
Campo, B.D.C. and Antonio, Katrien (2023). Insurance pricing with hierarchically structured data an illustration with a workers' compensation insurance portfolio. Scandinavian Actuarial Journal, doi: 10.1080/03461238.2022.2161413
Ohlsson, E. (2008). Combining generalized linear models and credibility models in practice. Scandinavian Actuarial Journal2008(4), 301–314.