weights is a generic function which extracts fitting weights from objects returned by modeling functions.
Methods can make use of napredict methods to compensate for the omission of missing values. The default methods does so.
# S3 method for cpglm
weights(object, type = c("prior", "working"), ...)# S3 method for hierCredGLM
weights(object, type = c("prior", "working"), ...)
# S3 method for hierCredTweedie
weights(object, type = c("prior", "working"), ...)
Weights extracted from the object object: the default method looks for component "weights" and if not NULL
calls napredict on it.
an object for which the extraction of model weights is meaningful. Can be either cpglm,
glm, hierCredibility, hierCredGLM or hierCredTweedie
indicates if prior or working weights need to be extracted.
ignored